@@ -162,8 +162,8 @@ class AristaL3Driver(object):
         registry.subscribe(self.update_network, resources.NETWORK,
                            events.AFTER_UPDATE)
 
-    def update_subnet(self, resource, event, trigger, **kwargs):
-        subnet_info = kwargs['subnet']
+    def update_subnet(self, resource, event, trigger, payload):
+        subnet_info = payload.latest_state
 
         if subnet_info['ip_version'] == 6:
             LOG.info('IPv6 networks not supported with L3 plugin')
@@ -188,9 +188,8 @@ class AristaL3Driver(object):
             self._delete_default_gateway(router_name)
             self._add_network_default_gateway(network_id)
 
-    def update_network(self, resource, event, trigger, **kwargs):
-        network_info = kwargs['network']
-        self._reset_network_default_route(network_info['id'])
+    def update_network(self, resource, event, trigger, payload):
+        self._reset_network_default_route(payload.resource_id)
 
     def _prepare_network_default_gateway(self, network_id):
         router_info = db_lib.get_network_gateway_ipv4(network_id)
